# Advanced Custom Accordions for WordPress

A powerful and flexible accordion plugin for WordPress that allows you to create beautiful, responsive accordions with multiple styles and customization options.

## Features

- 5 unique accordion styles (Classic, Modern, Material, Elegant, Bold)
- Fully responsive design
- Custom color schemes
- Drag-and-drop section reordering
- Rich text editor for content
- Live preview
- Shortcode support
- Accessibility compliant
- SEO friendly

## Installation

1. Upload the `advanced-custom-accordions` folder to the `/wp-content/plugins/` directory
2. Activate the plugin through the 'Plugins' menu in WordPress
3. Go to 'Accordions' in the WordPress admin menu to create your first accordion

## Usage

### Basic Usage

1. Go to Accordions → Add New
2. Give your accordion a title
3. Add sections using the "Add Section" button
4. Configure style and behavior settings
5. Use the generated shortcode in your posts or pages

### Shortcode

Basic usage:
```
[accordion id="123"]
```

Advanced usage:
```
[accordion id="123" style="modern" open_first="true" collapse_others="false"]
```

### Available Styles

1. Classic - Clean and professional design
2. Modern - Minimalist with fade effects
3. Material - Material Design inspired
4. Elegant - Sophisticated with serif fonts
5. Bold - High-contrast, impactful design

## Requirements

- WordPress 5.2 or higher
- PHP 7.4 or higher

## Developer Documentation

### Filters

```php
// Modify accordion settings
add_filter('aca_accordion_settings', function($settings, $post_id) {
    return $settings;
}, 10, 2);

// Customize style options
add_filter('aca_style_options', function($styles) {
    return $styles;
});
```

### Actions

```php
// Before accordion renders
do_action('aca_before_accordion', $post_id);

// After accordion renders
do_action('aca_after_accordion', $post_id);
```

## Contributing

Contributions are welcome! Please read our contributing guidelines before submitting a pull request.

## License

This project is licensed under the GPL v2 or later.

## Changelog

See [CHANGELOG.md](CHANGELOG.md) for a list of changes.