<?php
/**
 * Template for the plugin help page
 *
 * 
 * @package AdvancedCustomAccordions
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}
?>

<div class="wrap">
    <h1><?php _e('Advanced Custom Accordions Help', 'advanced-custom-accordions'); ?></h1>

    <div class="aca-help-wrapper">
        <!-- Quick Start Guide -->
        <div class="aca-help-section">
            <h2><?php _e('Quick Start Guide', 'advanced-custom-accordions'); ?></h2>
            <ol>
                <li>
                    <strong><?php _e('Create an Accordion:', 'advanced-custom-accordions'); ?></strong>
                    <p><?php _e('Go to Accordions → Add New to create your first accordion.', 'advanced-custom-accordions'); ?></p>
                </li>
                <li>
                    <strong><?php _e('Add Sections:', 'advanced-custom-accordions'); ?></strong>
                    <p><?php _e('Click "Add Section" to create accordion panels. Each section needs a title and content.', 'advanced-custom-accordions'); ?></p>
                </li>
                <li>
                    <strong><?php _e('Choose Style:', 'advanced-custom-accordions'); ?></strong>
                    <p><?php _e('Select from 5 pre-designed styles and customize colors to match your theme.', 'advanced-custom-accordions'); ?></p>
                </li>
                <li>
                    <strong><?php _e('Use Shortcode:', 'advanced-custom-accordions'); ?></strong>
                    <p><?php _e('Copy the shortcode and paste it into any post or page where you want the accordion to appear.', 'advanced-custom-accordions'); ?></p>
                </li>
            </ol>
        </div>

        <!-- Shortcode Reference -->
        <div class="aca-help-section">
            <h2><?php _e('Shortcode Reference', 'advanced-custom-accordions'); ?></h2>
            <p><?php _e('Basic usage:', 'advanced-custom-accordions'); ?></p>
            <code>[accordion id="123"]</code>

            <h3><?php _e('Available Parameters:', 'advanced-custom-accordions'); ?></h3>
            <table class="wp-list-table widefat fixed striped">
                <thead>
                    <tr>
                        <th><?php _e('Parameter', 'advanced-custom-accordions'); ?></th>
                        <th><?php _e('Description', 'advanced-custom-accordions'); ?></th>
                        <th><?php _e('Example', 'advanced-custom-accordions'); ?></th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td><code>id</code></td>
                        <td><?php _e('The accordion post ID (required)', 'advanced-custom-accordions'); ?></td>
                        <td><code>[accordion id="123"]</code></td>
                    </tr>
                    <tr>
                        <td><code>style</code></td>
                        <td><?php _e('Override the default style', 'advanced-custom-accordions'); ?></td>
                        <td><code>[accordion id="123" style="modern"]</code></td>
                    </tr>
                    <tr>
                        <td><code>open_first</code></td>
                        <td><?php _e('Open first section by default', 'advanced-custom-accordions'); ?></td>
                        <td><code>[accordion id="123" open_first="true"]</code></td>
                    </tr>
                    <tr>
                        <td><code>collapse_others</code></td>
                        <td><?php _e('Close other sections when opening one', 'advanced-custom-accordions'); ?></td>
                        <td><code>[accordion id="123" collapse_others="false"]</code></td>
                    </tr>
                </tbody>
            </table>
        </div>

        <!-- Styles Guide -->
        <div class="aca-help-section">
            <h2><?php _e('Available Styles', 'advanced-custom-accordions'); ?></h2>
            <table class="wp-list-table widefat fixed striped">
                <thead>
                    <tr>
                        <th><?php _e('Style Name', 'advanced-custom-accordions'); ?></th>
                        <th><?php _e('Description', 'advanced-custom-accordions'); ?></th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td><strong><?php _e('Classic', 'advanced-custom-accordions'); ?></strong></td>
                        <td><?php _e('Clean and professional design with smooth transitions.', 'advanced-custom-accordions'); ?></td>
                    </tr>
                    <tr>
                        <td><strong><?php _e('Modern', 'advanced-custom-accordions'); ?></strong></td>
                        <td><?php _e('Minimalist design with fade effects and rounded corners.', 'advanced-custom-accordions'); ?></td>
                    </tr>
                    <tr>
                        <td><strong><?php _e('Material', 'advanced-custom-accordions'); ?></strong></td>
                        <td><?php _e('Inspired by Material Design with ripple effects.', 'advanced-custom-accordions'); ?></td>
                    </tr>
                    <tr>
                        <td><strong><?php _e('Elegant', 'advanced-custom-accordions'); ?></strong></td>
                        <td><?php _e('Sophisticated design with serif fonts and gentle animations.', 'advanced-custom-accordions'); ?></td>
                    </tr>
                    <tr>
                        <td><strong><?php _e('Bold', 'advanced-custom-accordions'); ?></strong></td>
                        <td><?php _e('High-contrast design with strong visual hierarchy.', 'advanced-custom-accordions'); ?></td>
                    </tr>
                </tbody>
            </table>
        </div>

        <!-- FAQ -->
        <div class="aca-help-section">
            <h2><?php _e('Frequently Asked Questions', 'advanced-custom-accordions'); ?></h2>
            
            <div class="aca-faq-item">
                <h3><?php _e('Can I use multiple accordions on the same page?', 'advanced-custom-accordions'); ?></h3>
                <p><?php _e('Yes, you can use as many accordions as you need. Each accordion operates independently.', 'advanced-custom-accordions'); ?></p>
            </div>

            <div class="aca-faq-item">
                <h3><?php _e('Can I customize the colors?', 'advanced-custom-accordions'); ?></h3>
                <p><?php _e('Yes, each accordion can have its own color scheme. You can customize header colors, content colors, and borders.', 'advanced-custom-accordions'); ?></p>
            </div>

            <div class="aca-faq-item">
                <h3><?php _e('Is the plugin responsive?', 'advanced-custom-accordions'); ?></h3>
                <p><?php _e('Yes, all accordion styles are fully responsive and work well on mobile devices.', 'advanced-custom-accordions'); ?></p>
            </div>

            <div class="aca-faq-item">
                <h3><?php _e('Can I add images and videos in accordion content?', 'advanced-custom-accordions'); ?></h3>
                <p><?php _e('Yes, you can add any content that WordPress supports, including images, videos, and shortcodes.', 'advanced-custom-accordions'); ?></p>
            </div>
        </div>

        <!-- Support -->
        <div class="aca-help-section">
            <h2><?php _e('Need More Help?', 'advanced-custom-accordions'); ?></h2>
            <p>
                <?php _e('If you need additional assistance, please check our:', 'advanced-custom-accordions'); ?>
            </p>
            <ul>
                <li><a href="https://joevics.pro/documentation" target="_blank"><?php _e('Online Documentation', 'advanced-custom-accordions'); ?></a></li>
                <li><a href="https://joevics.pro/support" target="_blank"><?php _e('Support Forum', 'advanced-custom-accordions'); ?></a></li>
                <li><a href="https://joevics.pro/contact" target="_blank"><?php _e('Contact Us', 'advanced-custom-accordions'); ?></a></li>
            </ul>
        </div>
    </div>
</div>
<?php