<?php
/**
 * Template for the accordion sections metabox
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}
?>

<div class="aca-sections-metabox">
    <div class="aca-sections-toolbar">
        <button type="button" class="button button-primary" id="aca-add-section">
            <span class="dashicons dashicons-plus-alt2"></span>
            <?php _e('Add Section', 'advanced-custom-accordions'); ?>
        </button>
    </div>

    <div class="aca-sections-container">
        <?php
        if (!empty($sections)) :
            foreach ($sections as $index => $section) :
                ?>
                <div class="aca-section" data-index="<?php echo esc_attr($index); ?>">
                    <div class="aca-section-header">
                        <span class="aca-drag-handle dashicons dashicons-menu"></span>
                        <div class="aca-section-title">
                            <input type="text" 
                                   name="aca_sections[<?php echo esc_attr($index); ?>][title]" 
                                   value="<?php echo esc_attr($section['title']); ?>" 
                                   placeholder="<?php esc_attr_e('Section Title', 'advanced-custom-accordions'); ?>">
                        </div>
                        <div class="aca-section-actions">
                            <label class="aca-toggle-section">
                                <input type="checkbox" 
                                       name="aca_sections[<?php echo esc_attr($index); ?>][initial_state]" 
                                       value="1" 
                                       <?php checked(!empty($section['initial_state'])); ?>>
                                <?php esc_html_e('Initially Open', 'advanced-custom-accordions'); ?>
                            </label>
                            <button type="button" class="button aca-remove-section">
                                <span class="dashicons dashicons-trash"></span>
                            </button>
                        </div>
                    </div>
                    <div class="aca-section-content">
                        <?php
                        wp_editor(
                            $section['content'],
                            'aca_section_content_' . $index,
                            array(
                                'textarea_name' => 'aca_sections[' . $index . '][content]',
                                'media_buttons' => true,
                                'textarea_rows' => 10,
                                'editor_height' => 200,
                                'editor_class' => 'aca-section-editor',
                                'teeny' => false
                            )
                        );
                        ?>
                    </div>
                </div>
                <?php
            endforeach;
        endif;
        ?>
    </div>

    <div class="aca-sections-empty <?php echo empty($sections) ? '' : 'hidden'; ?>">
        <p><?php _e('No sections added yet. Click the "Add Section" button to create your first accordion section.', 'advanced-custom-accordions'); ?></p>
    </div>

    <div class="aca-sections-bottom-toolbar <?php echo empty($sections) ? 'hidden' : ''; ?>">
        <button type="button" class="button button-primary" id="aca-add-section-bottom">
            <span class="dashicons dashicons-plus-alt2"></span>
            <?php _e('Add Section', 'advanced-custom-accordions'); ?>
        </button>
    </div>
</div>
<?php