<?php
/**
 * Template for the accordion settings metabox
 *
 * 
 * @package AdvancedCustomAccordions
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

$styles = ACA_Helper::get_accordion_styles();
?>

<div class="aca-settings-metabox">
    <!-- Style Selection -->
    <div class="aca-field-row">
        <label for="aca_style" class="aca-label">
            <?php _e('Accordion Style', 'advanced-custom-accordions'); ?>
        </label>
        <select id="aca_style" name="aca_style" class="widefat">
            <?php foreach ($styles as $key => $style_data) : ?>
                <option value="<?php echo esc_attr($key); ?>" <?php selected($style, $key); ?>>
                    <?php echo esc_html($style_data['label']); ?>
                </option>
            <?php endforeach; ?>
        </select>
        <p class="description style-description"></p>
    </div>

    <!-- Live Preview -->
    <div class="aca-style-preview-wrapper">
        <h4><?php _e('Accordion Preview', 'advanced-custom-accordions'); ?></h4>
        <div class="aca-preview-header">
            <div class="aca-preview-title">
                <span class="description"><?php _e('Preview updates automatically as you make changes. Make a change to see the updated preview.', 'advanced-custom-accordions'); ?></span>
            </div>
            <button type="button" class="button" id="aca-refresh-preview">
                <span class="dashicons dashicons-update"></span>
                <?php _e('Refresh Preview', 'advanced-custom-accordions'); ?>
            </button>
        </div>
        <div class="aca-preview-container">
            <div id="aca-accordion-preview" class="aca-preview-content">
                <div class="aca-preview-loading">
                    <span class="spinner is-active"></span>
                    <?php _e('Loading preview...', 'advanced-custom-accordions'); ?>
                </div>
            </div>
        </div>
    </div>

    <!-- Color Settings -->
    <div class="aca-color-settings">
        <h4><?php _e('Color Settings', 'advanced-custom-accordions'); ?></h4>
        <div class="aca-color-picker-wrapper">
            <div class="aca-color-field">
                <label for="aca_colors_header_bg">
                    <?php _e('Header Background', 'advanced-custom-accordions'); ?>
                </label>
                <input type="text" 
                       id="aca_colors_header_bg" 
                       name="aca_colors[header_bg]" 
                       value="<?php echo esc_attr($colors['header_bg']); ?>" 
                       class="aca-color-picker" 
                       data-default-color="<?php echo esc_attr($default_colors['header_bg']); ?>">
            </div>

            <div class="aca-color-field">
                <label for="aca_colors_header_text">
                    <?php _e('Header Text', 'advanced-custom-accordions'); ?>
                </label>
                <input type="text" 
                       id="aca_colors_header_text" 
                       name="aca_colors[header_text]" 
                       value="<?php echo esc_attr($colors['header_text']); ?>" 
                       class="aca-color-picker" 
                       data-default-color="<?php echo esc_attr($default_colors['header_text']); ?>">
            </div>

            <div class="aca-color-field">
                <label for="aca_colors_header_bg_active">
                    <?php _e('Active Header Background', 'advanced-custom-accordions'); ?>
                </label>
                <input type="text" 
                       id="aca_colors_header_bg_active" 
                       name="aca_colors[header_bg_active]" 
                       value="<?php echo esc_attr($colors['header_bg_active']); ?>" 
                       class="aca-color-picker" 
                       data-default-color="<?php echo esc_attr($default_colors['header_bg_active']); ?>">
            </div>

            <div class="aca-color-field">
                <label for="aca_colors_header_text_active">
                    <?php _e('Active Header Text', 'advanced-custom-accordions'); ?>
                </label>
                <input type="text" 
                       id="aca_colors_header_text_active" 
                       name="aca_colors[header_text_active]" 
                       value="<?php echo esc_attr($colors['header_text_active']); ?>" 
                       class="aca-color-picker" 
                       data-default-color="<?php echo esc_attr($default_colors['header_text_active']); ?>">
            </div>

            <div class="aca-color-field">
                <label for="aca_colors_content_bg">
                    <?php _e('Content Background', 'advanced-custom-accordions'); ?>
                </label>
                <input type="text" 
                       id="aca_colors_content_bg" 
                       name="aca_colors[content_bg]" 
                       value="<?php echo esc_attr($colors['content_bg']); ?>" 
                       class="aca-color-picker" 
                       data-default-color="<?php echo esc_attr($default_colors['content_bg']); ?>">
            </div>

            <div class="aca-color-field">
                <label for="aca_colors_content_text">
                    <?php _e('Content Text', 'advanced-custom-accordions'); ?>
                </label>
                <input type="text" 
                       id="aca_colors_content_text" 
                       name="aca_colors[content_text]" 
                       value="<?php echo esc_attr($colors['content_text']); ?>" 
                       class="aca-color-picker" 
                       data-default-color="<?php echo esc_attr($default_colors['content_text']); ?>">
            </div>

            <div class="aca-color-field">
                <label for="aca_colors_border_color">
                    <?php _e('Border Color', 'advanced-custom-accordions'); ?>
                </label>
                <input type="text" 
                       id="aca_colors_border_color" 
                       name="aca_colors[border_color]" 
                       value="<?php echo esc_attr($colors['border_color']); ?>" 
                       class="aca-color-picker" 
                       data-default-color="<?php echo esc_attr($default_colors['border_color']); ?>">
            </div>
        </div>
    </div>

    <!-- Behavior Settings -->
    <div class="aca-behavior-settings">
        <h4><?php _e('Behavior Settings', 'advanced-custom-accordions'); ?></h4>
        
        <div class="aca-field-row">
            <label>
                <input type="checkbox" 
                       id="aca_settings_collapse_others" 
                       name="aca_settings[collapse_others]" 
                       value="1" 
                       <?php checked($settings['collapse_others']); ?>>
                <?php _e('Close other sections when opening one', 'advanced-custom-accordions'); ?>
            </label>
        </div>

        <div class="aca-field-row">
            <label>
                <input type="checkbox" 
                       id="aca_settings_scroll_to_top" 
                       name="aca_settings[scroll_to_top]" 
                       value="1" 
                       <?php checked($settings['scroll_to_top']); ?>>
                <?php _e('Scroll to top of section when opening', 'advanced-custom-accordions'); ?>
            </label>
        </div>

        <div class="aca-field-row">
            <label for="aca_settings_initial_open">
                <?php _e('Initially Open Section', 'advanced-custom-accordions'); ?>
            </label>
            <select id="aca_settings_initial_open" 
                    name="aca_settings[initial_open]" 
                    class="widefat">
                <option value="-1" <?php selected($settings['initial_open'], -1); ?>>
                    <?php _e('None', 'advanced-custom-accordions'); ?>
                </option>
                <option value="0" <?php selected($settings['initial_open'], 0); ?>>
                    <?php _e('First Section', 'advanced-custom-accordions'); ?>
                </option>
                <?php for ($i = 1; $i < 10; $i++) : ?>
                    <option value="<?php echo $i; ?>" <?php selected($settings['initial_open'], $i); ?>>
                        <?php printf(__('Section %d', 'advanced-custom-accordions'), $i + 1); ?>
                    </option>
                <?php endfor; ?>
            </select>
        </div>
    </div>
</div>

<style>
.aca-style-preview-wrapper {
    margin: 20px 0;
    background: #fff;
    border: 1px solid #e5e5e5;
}

.aca-preview-header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 15px;
    background: #f8f9fa;
    border-bottom: 1px solid #e5e5e5;
}

.aca-preview-container {
    padding: 20px;
    min-height: 200px;
}

.aca-preview-loading {
    text-align: center;
    padding: 40px 20px;
    color: #666;
}

.aca-preview-loading .spinner {
    float: none;
    margin: 0 auto 10px;
    display: block;
}

.aca-preview-title h4 {
    margin: 0 0 5px 0;
}

.aca-preview-title .description {
    color: #666;
}
</style>
<?php