<?php
/**
 * Template for the plugin settings page
 *
 * 
 * @package AdvancedCustomAccordions
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}
?>

<div class="wrap">
    <h1><?php echo esc_html(get_admin_page_title()); ?></h1>

    <?php settings_errors('aca_settings'); ?>

    <form method="post" action="">
        <?php wp_nonce_field('aca_settings_nonce'); ?>

        <div class="aca-settings-wrapper">
            <!-- General Settings -->
            <div class="aca-settings-group">
                <h2><?php _e('General Settings', 'advanced-custom-accordions'); ?></h2>
                
                <table class="form-table">
                    <tr>
                        <th scope="row">
                            <label for="enable_preview">
                                <?php _e('Enable Live Preview', 'advanced-custom-accordions'); ?>
                            </label>
                        </th>
                        <td>
                            <label>
                                <input type="checkbox" 
                                       id="enable_preview" 
                                       name="enable_preview" 
                                       value="1" 
                                       <?php checked(isset($settings['enable_preview'])); ?>>
                                <?php _e('Show live preview in accordion editor', 'advanced-custom-accordions'); ?>
                            </label>
                            <p class="description">
                                <?php _e('Preview changes in real-time while editing accordions.', 'advanced-custom-accordions'); ?>
                            </p>
                        </td>
                    </tr>

                    <tr>
                        <th scope="row">
                            <label for="animation_speed">
                                <?php _e('Animation Speed', 'advanced-custom-accordions'); ?>
                            </label>
                        </th>
                        <td>
                            <input type="number" 
                                   id="animation_speed" 
                                   name="animation_speed" 
                                   value="<?php echo esc_attr($settings['animation_speed'] ?? 300); ?>"
                                   min="0" 
                                   max="2000" 
                                   step="50"
                                   class="small-text">
                            <p class="description">
                                <?php _e('Duration of opening/closing animations in milliseconds.', 'advanced-custom-accordions'); ?>
                            </p>
                        </td>
                    </tr>

                    <tr>
                        <th scope="row">
                            <label for="load_font_awesome">
                                <?php _e('Load Font Awesome', 'advanced-custom-accordions'); ?>
                            </label>
                        </th>
                        <td>
                            <label>
                                <input type="checkbox" 
                                       id="load_font_awesome" 
                                       name="load_font_awesome" 
                                       value="1" 
                                       <?php checked(isset($settings['load_font_awesome'])); ?>>
                                <?php _e('Load Font Awesome icons', 'advanced-custom-accordions'); ?>
                            </label>
                            <p class="description">
                                <?php _e('Enable if your theme doesn\'t include Font Awesome.', 'advanced-custom-accordions'); ?>
                            </p>
                        </td>
                    </tr>
                </table>
            </div>

            <!-- Style Settings -->
            <div class="aca-settings-group">
                <h2><?php _e('Style Settings', 'advanced-custom-accordions'); ?></h2>
                
                <table class="form-table">
                    <tr>
                        <th scope="row">
                            <label for="custom_css">
                                <?php _e('Custom CSS', 'advanced-custom-accordions'); ?>
                            </label>
                        </th>
                        <td>
                            <textarea id="custom_css" 
                                      name="custom_css" 
                                      rows="10" 
                                      class="large-text code"><?php echo esc_textarea($settings['custom_css'] ?? ''); ?></textarea>
                            <p class="description">
                                <?php _e('Add custom CSS styles for your accordions. These styles will be applied globally.', 'advanced-custom-accordions'); ?>
                            </p>
                        </td>
                    </tr>
                </table>
            </div>

            <!-- Advanced Settings -->
            <div class="aca-settings-group">
                <h2><?php _e('Advanced Settings', 'advanced-custom-accordions'); ?></h2>
                
                <table class="form-table">
                    <tr>
                        <th scope="row">
                            <label for="scroll_offset">
                                <?php _e('Scroll Offset', 'advanced-custom-accordions'); ?>
                            </label>
                        </th>
                        <td>
                            <input type="number" 
                                   id="scroll_offset" 
                                   name="scroll_offset" 
                                   value="<?php echo esc_attr($settings['scroll_offset'] ?? 100); ?>"
                                   min="0" 
                                   max="500" 
                                   class="small-text">
                            <p class="description">
                                <?php _e('Distance in pixels from the top of the window when scrolling to an accordion section.', 'advanced-custom-accordions'); ?>
                            </p>
                        </td>
                    </tr>

                    <tr>
                        <th scope="row">
                            <label for="disable_wrap_links">
                                <?php _e('URL Handling', 'advanced-custom-accordions'); ?>
                            </label>
                        </th>
                        <td>
                            <label>
                                <input type="checkbox" 
                                       id="disable_wrap_links" 
                                       name="disable_wrap_links" 
                                       value="1" 
                                       <?php checked(isset($settings['disable_wrap_links'])); ?>>
                                <?php _e('Disable automatic link wrapping in accordion content', 'advanced-custom-accordions'); ?>
                            </label>
                            <p class="description">
                                <?php _e('By default, URLs in accordion content are automatically converted to clickable links.', 'advanced-custom-accordions'); ?>
                            </p>
                        </td>
                    </tr>
                </table>
            </div>
        </div>

        <?php submit_button(__('Save Settings', 'advanced-custom-accordions'), 'primary', 'aca_save_settings'); ?>
    </form>
</div>
</div>
<?php